==> aar_multi_chip-1.1.48-sources.jar: com/xdja/multichip/process/cardstatus/CardStatusProvider.java <==
package com.xdja.multichip.process.cardstatus;

import android.content.ContentProvider;
import android.content.ContentValues;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import static com.xdja.multichip.param.ParamKeywords.KEY_Binder_Binder;
import static com.xdja.multichip.param.ParamKeywords.KEY_METHOD_CardStatusBinder;
import static com.xdja.multichip.param.ParamKeywords.KEY_METHOD_GetBinder;
import static com.xdja.multichip.param.ParamKeywords.KEY_int_ret;

/**
 * @author: zhangxiaolong@xdja.com <br/>
 * date:   2018/5/16 <br/>
 */
public class CardStatusProvider extends ContentProvider {

    @Override
    public boolean onCreate() {
        startTheService();
        return false;
    }

    @Nullable
    @Override
    public Cursor query(@NonNull Uri uri, @Nullable String[] projection, @Nullable String selection, @Nullable String[] selectionArgs, @Nullable String sortOrder) {
        return null;
    }

    @Nullable
    @Override
    public String getType(@NonNull Uri uri) {
        return null;
    }

    @Nullable
    @Override
    public Uri insert(@NonNull Uri uri, @Nullable ContentValues values) {
        return null;
    }

    @Override
    public int delete(@NonNull Uri uri, @Nullable String selection, @Nullable String[] selectionArgs) {
        return 0;
    }

    @Override
    public int update(@NonNull Uri uri, @Nullable ContentValues values, @Nullable String selection, @Nullable String[] selectionArgs) {
        return 0;
    }

    @Nullable
    @Override
    public Bundle call(@NonNull String method, @Nullable String arg, @Nullable Bundle extras) {
        if (KEY_METHOD_GetBinder.equals(method) && KEY_METHOD_CardStatusBinder.equals(arg)) {
            Bundle result = new Bundle();
            result.putInt(KEY_int_ret, 0);
            result.putBinder(KEY_Binder_Binder, CardStatusBinderService.getInstance(getContext()).asBinder());
            return result;
        }
        return super.call(method, arg, extras);
    }

    private void startTheService() {
        Intent intent = new Intent();
        intent.setClass(getContext(), CardStatusService.class);
        getContext().startService(intent);
    }
}

==> aar_multi_chip-1.1.121-sources.jar: com/xdja/multichip/process/cardstatus/CardStatusProvider.java <==
package com.xdja.multichip.process.cardstatus;

import android.content.ContentProvider;
import android.content.ContentValues;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;


import com.xdja.multichip.compat.ServiceCompatXdja;

import static com.xdja.multichip.param.ParamKeywords.KEY_Binder_Binder;
import static com.xdja.multichip.param.ParamKeywords.KEY_METHOD_CardStatusBinder;
import static com.xdja.multichip.param.ParamKeywords.KEY_METHOD_GetBinder;
import static com.xdja.multichip.param.ParamKeywords.KEY_int_ret;

/**
 * @author: zhangxiaolong@xdja.com <br/>
 * date:   2018/5/16 <br/>
 */
public class CardStatusProvider extends ContentProvider {

    @Override
    public boolean onCreate() {
        startTheService();
        return false;
    }


    @Override
    public Cursor query(Uri uri, String[] projection, String selection, String[] selectionArgs, String sortOrder) {
        return null;
    }


    @Override
    public String getType(Uri uri) {
        return null;
    }


    @Override
    public Uri insert(Uri uri, ContentValues values) {
        return null;
    }

    @Override
    public int delete(Uri uri, String selection, String[] selectionArgs) {
        return 0;
    }

    @Override
    public int update(Uri uri, ContentValues values, String selection, String[] selectionArgs) {
        return 0;
    }


    @Override
    public Bundle call(String method, String arg, Bundle extras) {
        if (KEY_METHOD_GetBinder.equals(method) && KEY_METHOD_CardStatusBinder.equals(arg)) {
            Bundle result = new Bundle();
            result.putInt(KEY_int_ret, 0);
            result.putBinder(KEY_Binder_Binder, CardStatusBinderService.getInstance(getContext()).asBinder());
            return result;
        }
        return super.call(method, arg, extras);
    }

    private void startTheService() {
        Intent intent = new Intent();
        intent.setClass(getContext(), CardStatusService.class);
        ServiceCompatXdja.startService(getContext(),intent);
    }
}
